/* getgid - print GID of given group
   Copyright (C) 1999 Artur Frysiak <wiget@pld-linux.org>

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software Foundation,
   Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.  */

#include <config.h>
#include <grp.h>
#include <sys/types.h>
#include <getopt.h>
#include "system.h"
#include "quote.h"
#include "error.h"

#define PROGRAM_NAME "getgid"

#define AUTHORS proper_name ("Artur Frysiak")

/* The name by which this program was run. */
const char *program_name;

static struct option const longopts[] =
{
  {GETOPT_HELP_OPTION_DECL},
  {GETOPT_VERSION_OPTION_DECL},
  {NULL, 0, NULL, 0}
};

void
usage (int status)
{
  if (status != EXIT_SUCCESS)
    fprintf (stderr, _("Try `%s --help' for more information.\n"),
             program_name);
  else
    {
      printf (_("\
Usage: %s [OPTION]... [GROUPNAME]...\n\
"),
              program_name);
      fputs (_("\
Prints ID of given group name.\
\n\
"), stdout);
      fputs (HELP_OPTION_DESCRIPTION, stdout);
      fputs (VERSION_OPTION_DESCRIPTION, stdout);
      emit_bug_reporting_address ();
    }
  exit (status);
}

int main(int argc, char **argv)
{
	struct group 	*gr;
	int		optc;

	initialize_main (&argc, &argv);
	program_name = argv[0];

	setlocale (LC_ALL, "");
	bindtextdomain (PACKAGE, LOCALEDIR);
	textdomain (PACKAGE);

	atexit (close_stdout);

	while ((optc = getopt_long (argc, argv, "+", longopts, NULL)) != -1) {
		switch (optc) {
			case_GETOPT_HELP_CHAR;
			case_GETOPT_VERSION_CHAR (PROGRAM_NAME, AUTHORS);
		default:
			usage (EXIT_FAILURE);
		}
	}

	if (argc < optind + 1)
	{
		error (0, 0, _("missing operand"));
		usage (EXIT_FAILURE);
	}

	if (optind + 2 < argc)
	{
		error (0, 0, _("extra operand %s"), quote (argv[optind + 2]));
		usage (EXIT_FAILURE);
	}

	gr = getgrnam(argv[optind]);
	if (gr == NULL) {
		error (0, 0, _("cannot find group name %s"), quote(argv[optind]));
		exit(EXIT_FAILURE);
	} else
		printf("%lu\n", (unsigned long int) gr->gr_gid);
	exit(EXIT_SUCCESS);
}

